@@ -17,7 +17,7 @@ except:
 	sys.exit(1)
 
 import hildon
-#import osso
+import osso
 import conic
 #import dbus
 
@@ -58,7 +58,7 @@ class rdpThread(threading.Thread) :
 			return False
 		#print "rdesktop-cli " + self.parameters + " " + self.host
                 self.ossoc = osso.Context("pyrdesktop", "1.6.0", False)
-                self.note = osso.SystemNote(self.ossoc)
+		self.note = osso.SystemNote(self.ossoc)
                 self.note.system_note_infoprint("Connecting to '" + self.name + "'")
 		result = os.system("rdesktop-cli " + self.parameters + " " + self.host)
 		needEnter = False
@@ -208,6 +208,9 @@ class rdesktop:
 		self.host.set_property('hildon-input-mode', (1 << 0 | 1 << 1 | 1 << 2))
 		self.username.set_property('hildon-input-mode', (1 << 0 | 1 << 1 | 1 << 2))
 		self.password.set_property('hildon-input-mode', (1 << 0 | 1 << 1 | 1 << 2 | 1 << 29))
+		
+		#Keep track of which profile is selected -- This will be the number as a string ex: "1"
+		self.current_profile = ""
 
 		#Setup GConf and load profiles
 		self.client = gconf.client_get_default()
@@ -229,9 +232,6 @@ class rdesktop:
 		self.about_dialog = None  #-- Not sure if I need these two
 		self.error_dialog = None  #-- lines...
 
-		#Keep track of which profile is selected -- This will be the number as a string ex: "1"
-		self.current_profile = ""
-
 		dic = {
 			# Process signal from button
 			"connect" : self.connect,
@@ -249,7 +249,7 @@ class rdesktop:
                         "exp_preset_change" : self.exp_preset_change,
                         "change_exp" : self.change_exp}
 		self.wTree.signal_autoconnect(dic)
-
+		
 	def ErrPopUp(self,msg):
 		error_dialog = gtk.MessageDialog(None,0,gtk.MESSAGE_ERROR,gtk.BUTTONS_CLOSE,msg)
 		def close(dialog, response, editor):
@@ -279,18 +279,20 @@ class rdesktop:
                 #I was smart when writing this function, to avoid rewriting code
                 #The presets just add on themselves going up...
                 self.changing_preset = True
-                self.reset_exp_checks()
-                if self.cmb_exp_preset.get_active() >= 0 :
-                        self.chk_exp_bitmap.set_active(True)
-                if self.cmb_exp_preset.get_active() >= 1 :
-                        self.chk_exp_themes.set_active(True)
-                if self.cmb_exp_preset.get_active() >= 2 :
-                        self.chk_exp_animation.set_active(True)
-                        self.chk_exp_drag.set_active(True)
-                        self.chk_exp_composition.set_active(True)
-                if self.cmb_exp_preset.get_active() >= 3 :
-                        self.chk_exp_font.set_active(True)
-                        self.chk_exp_desktop.set_active(True)
+		preset = self.cmb_exp_preset.get_active()
+		if preset < 4 :
+		    self.reset_exp_checks()
+		    if preset >= 0 :
+			    self.chk_exp_bitmap.set_active(True)
+		    if preset >= 1 :
+			    self.chk_exp_themes.set_active(True)
+		    if preset >= 2 :
+			    self.chk_exp_animation.set_active(True)
+			    self.chk_exp_drag.set_active(True)
+			    self.chk_exp_composition.set_active(True)
+		    if preset >= 3 :
+			    self.chk_exp_font.set_active(True)
+			    self.chk_exp_desktop.set_active(True)
                 #if self.cmb_exp_preset.get_active() == 4 :
                 #        self.reset_exp_checks()
                 #At first, I thought selecting "Custom" should clear the checkboxes...
@@ -471,7 +473,7 @@ class rdesktop:
 		# But that's ok, because we don't need to do anything with it!
 
 	def cancel(self,widget) :
-		print "quitting @ cancel...?"
+		#print "quitting @ cancel...?"
 		if self.current_profile != "" :
 			self.client.set_string("/apps/rdesktop/load_prof", self.current_profile)
 		gtk.main_quit()
@@ -596,4 +598,4 @@ if __name__ == "__main__":
 	#	time.sleep(1)
 	#sys.exit(1)
 	time.sleep(1)
-	print "Quitting... ?"
+	#print "Quitting... ?"
